Module DecimalFloat

Module DecimalFloat 

Generated by the following Solidity interface…

interface DecimalFloat {
    type Float is bytes32;

    error CoefficientOverflow(int256 signedCoefficient, int256 exponent);
    error DivisionByZero(int256 signedCoefficient, int256 exponent);
    error ExponentOverflow(int256 signedCoefficient, int256 exponent);
    error ExponentUnderflow(int256 signedCoefficient, int256 exponent);
    error FixedDecimalOverflow(int256 signedCoefficient, int256 exponent, uint8 decimals);
    error Log10Negative(int256 signedCoefficient, int256 exponent);
    error Log10Zero();
    error LogTablesNotDeployed(address tablesAddress, bytes32 expectedCodehash, bytes32 actualCodehash);
    error LossyConversionFromFloat(int256 signedCoefficient, int256 exponent);
    error LossyConversionToFloat(int256 signedCoefficient, int256 exponent);
    error MaximizeOverflow(int256 signedCoefficient, int256 exponent);
    error MulDivOverflow(uint256 x, uint256 y, uint256 denominator);
    error NegativeFixedDecimalConversion(int256 signedCoefficient, int256 exponent);
    error PowNegativeBase(int256 signedCoefficient, int256 exponent);
    error ScientificMinNotLessThanMax(Float scientificMin, Float scientificMax);
    error UnformatableExponent(int256 exponent);
    error WithTargetExponentOverflow(int256 signedCoefficient, int256 exponent, int256 targetExponent);
    error ZeroNegativePower(Float b);
    error ZeroStringStartPointer();

    constructor();

    function FORMAT_DEFAULT_SCIENTIFIC_MAX() external view returns (Float);
    function FORMAT_DEFAULT_SCIENTIFIC_MIN() external view returns (Float);
    function abs(Float a) external pure returns (Float);
    function add(Float a, Float b) external pure returns (Float);
    function ceil(Float a) external pure returns (Float);
    function div(Float a, Float b) external pure returns (Float);
    function e() external pure returns (Float);
    function eq(Float a, Float b) external pure returns (bool);
    function floor(Float a) external pure returns (Float);
    function format(Float a, bool scientific) external pure returns (string memory);
    function format(Float a) external pure returns (string memory);
    function format(Float a, Float scientificMin, Float scientificMax) external pure returns (string memory);
    function frac(Float a) external pure returns (Float);
    function fromFixedDecimalLossless(uint256 value, uint8 decimals) external pure returns (Float);
    function fromFixedDecimalLossy(uint256 value, uint8 decimals) external pure returns (Float, bool);
    function gt(Float a, Float b) external pure returns (bool);
    function gte(Float a, Float b) external pure returns (bool);
    function integer(Float a) external pure returns (Float);
    function inv(Float a) external pure returns (Float);
    function isZero(Float a) external pure returns (bool);
    function log10(Float a) external view returns (Float);
    function lt(Float a, Float b) external pure returns (bool);
    function lte(Float a, Float b) external pure returns (bool);
    function max(Float a, Float b) external pure returns (Float);
    function maxNegativeValue() external pure returns (Float);
    function maxPositiveValue() external pure returns (Float);
    function min(Float a, Float b) external pure returns (Float);
    function minNegativeValue() external pure returns (Float);
    function minPositiveValue() external pure returns (Float);
    function minus(Float a) external pure returns (Float);
    function mul(Float a, Float b) external pure returns (Float);
    function parse(string memory str) external pure returns (bytes4, Float);
    function pow(Float a, Float b) external view returns (Float);
    function pow10(Float a) external view returns (Float);
    function sqrt(Float a) external view returns (Float);
    function sub(Float a, Float b) external pure returns (Float);
    function toFixedDecimalLossless(Float float, uint8 decimals) external pure returns (uint256);
    function toFixedDecimalLossy(Float float, uint8 decimals) external pure returns (uint256, bool);
    function zero() external pure returns (Float);
}

…which was generated by the following JSON ABI:

[
  {
    "type": "constructor",
    "inputs": [],
    "stateMutability": "nonpayable"
  },
  {
    "type": "function",
    "name": "FORMAT_DEFAULT_SCIENTIFIC_MAX",
    "inputs": [],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "view"
  },
  {
    "type": "function",
    "name": "FORMAT_DEFAULT_SCIENTIFIC_MIN",
    "inputs": [],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "view"
  },
  {
    "type": "function",
    "name": "abs",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "add",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      },
      {
        "name": "b",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "ceil",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "div",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      },
      {
        "name": "b",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "e",
    "inputs": [],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "eq",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      },
      {
        "name": "b",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bool",
        "internalType": "bool"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "floor",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "format",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      },
      {
        "name": "scientific",
        "type": "bool",
        "internalType": "bool"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "string",
        "internalType": "string"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "format",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "string",
        "internalType": "string"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "format",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      },
      {
        "name": "scientificMin",
        "type": "bytes32",
        "internalType": "Float"
      },
      {
        "name": "scientificMax",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "string",
        "internalType": "string"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "frac",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "fromFixedDecimalLossless",
    "inputs": [
      {
        "name": "value",
        "type": "uint256",
        "internalType": "uint256"
      },
      {
        "name": "decimals",
        "type": "uint8",
        "internalType": "uint8"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "fromFixedDecimalLossy",
    "inputs": [
      {
        "name": "value",
        "type": "uint256",
        "internalType": "uint256"
      },
      {
        "name": "decimals",
        "type": "uint8",
        "internalType": "uint8"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      },
      {
        "name": "",
        "type": "bool",
        "internalType": "bool"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "gt",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      },
      {
        "name": "b",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bool",
        "internalType": "bool"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "gte",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      },
      {
        "name": "b",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bool",
        "internalType": "bool"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "integer",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "inv",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "isZero",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bool",
        "internalType": "bool"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "log10",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "view"
  },
  {
    "type": "function",
    "name": "lt",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      },
      {
        "name": "b",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bool",
        "internalType": "bool"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "lte",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      },
      {
        "name": "b",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bool",
        "internalType": "bool"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "max",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      },
      {
        "name": "b",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "maxNegativeValue",
    "inputs": [],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "maxPositiveValue",
    "inputs": [],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "min",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      },
      {
        "name": "b",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "minNegativeValue",
    "inputs": [],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "minPositiveValue",
    "inputs": [],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "minus",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "mul",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      },
      {
        "name": "b",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "parse",
    "inputs": [
      {
        "name": "str",
        "type": "string",
        "internalType": "string"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bytes4",
        "internalType": "bytes4"
      },
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "pow",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      },
      {
        "name": "b",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "view"
  },
  {
    "type": "function",
    "name": "pow10",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "view"
  },
  {
    "type": "function",
    "name": "sqrt",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "view"
  },
  {
    "type": "function",
    "name": "sub",
    "inputs": [
      {
        "name": "a",
        "type": "bytes32",
        "internalType": "Float"
      },
      {
        "name": "b",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "toFixedDecimalLossless",
    "inputs": [
      {
        "name": "float",
        "type": "bytes32",
        "internalType": "Float"
      },
      {
        "name": "decimals",
        "type": "uint8",
        "internalType": "uint8"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "uint256",
        "internalType": "uint256"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "toFixedDecimalLossy",
    "inputs": [
      {
        "name": "float",
        "type": "bytes32",
        "internalType": "Float"
      },
      {
        "name": "decimals",
        "type": "uint8",
        "internalType": "uint8"
      }
    ],
    "outputs": [
      {
        "name": "",
        "type": "uint256",
        "internalType": "uint256"
      },
      {
        "name": "",
        "type": "bool",
        "internalType": "bool"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "function",
    "name": "zero",
    "inputs": [],
    "outputs": [
      {
        "name": "",
        "type": "bytes32",
        "internalType": "Float"
      }
    ],
    "stateMutability": "pure"
  },
  {
    "type": "error",
    "name": "CoefficientOverflow",
    "inputs": [
      {
        "name": "signedCoefficient",
        "type": "int256",
        "internalType": "int256"
      },
      {
        "name": "exponent",
        "type": "int256",
        "internalType": "int256"
      }
    ]
  },
  {
    "type": "error",
    "name": "DivisionByZero",
    "inputs": [
      {
        "name": "signedCoefficient",
        "type": "int256",
        "internalType": "int256"
      },
      {
        "name": "exponent",
        "type": "int256",
        "internalType": "int256"
      }
    ]
  },
  {
    "type": "error",
    "name": "ExponentOverflow",
    "inputs": [
      {
        "name": "signedCoefficient",
        "type": "int256",
        "internalType": "int256"
      },
      {
        "name": "exponent",
        "type": "int256",
        "internalType": "int256"
      }
    ]
  },
  {
    "type": "error",
    "name": "ExponentUnderflow",
    "inputs": [
      {
        "name": "signedCoefficient",
        "type": "int256",
        "internalType": "int256"
      },
      {
        "name": "exponent",
        "type": "int256",
        "internalType": "int256"
      }
    ]
  },
  {
    "type": "error",
    "name": "FixedDecimalOverflow",
    "inputs": [
      {
        "name": "signedCoefficient",
        "type": "int256",
        "internalType": "int256"
      },
      {
        "name": "exponent",
        "type": "int256",
        "internalType": "int256"
      },
      {
        "name": "decimals",
        "type": "uint8",
        "internalType": "uint8"
      }
    ]
  },
  {
    "type": "error",
    "name": "Log10Negative",
    "inputs": [
      {
        "name": "signedCoefficient",
        "type": "int256",
        "internalType": "int256"
      },
      {
        "name": "exponent",
        "type": "int256",
        "internalType": "int256"
      }
    ]
  },
  {
    "type": "error",
    "name": "Log10Zero",
    "inputs": []
  },
  {
    "type": "error",
    "name": "LogTablesNotDeployed",
    "inputs": [
      {
        "name": "tablesAddress",
        "type": "address",
        "internalType": "address"
      },
      {
        "name": "expectedCodehash",
        "type": "bytes32",
        "internalType": "bytes32"
      },
      {
        "name": "actualCodehash",
        "type": "bytes32",
        "internalType": "bytes32"
      }
    ]
  },
  {
    "type": "error",
    "name": "LossyConversionFromFloat",
    "inputs": [
      {
        "name": "signedCoefficient",
        "type": "int256",
        "internalType": "int256"
      },
      {
        "name": "exponent",
        "type": "int256",
        "internalType": "int256"
      }
    ]
  },
  {
    "type": "error",
    "name": "LossyConversionToFloat",
    "inputs": [
      {
        "name": "signedCoefficient",
        "type": "int256",
        "internalType": "int256"
      },
      {
        "name": "exponent",
        "type": "int256",
        "internalType": "int256"
      }
    ]
  },
  {
    "type": "error",
    "name": "MaximizeOverflow",
    "inputs": [
      {
        "name": "signedCoefficient",
        "type": "int256",
        "internalType": "int256"
      },
      {
        "name": "exponent",
        "type": "int256",
        "internalType": "int256"
      }
    ]
  },
  {
    "type": "error",
    "name": "MulDivOverflow",
    "inputs": [
      {
        "name": "x",
        "type": "uint256",
        "internalType": "uint256"
      },
      {
        "name": "y",
        "type": "uint256",
        "internalType": "uint256"
      },
      {
        "name": "denominator",
        "type": "uint256",
        "internalType": "uint256"
      }
    ]
  },
  {
    "type": "error",
    "name": "NegativeFixedDecimalConversion",
    "inputs": [
      {
        "name": "signedCoefficient",
        "type": "int256",
        "internalType": "int256"
      },
      {
        "name": "exponent",
        "type": "int256",
        "internalType": "int256"
      }
    ]
  },
  {
    "type": "error",
    "name": "PowNegativeBase",
    "inputs": [
      {
        "name": "signedCoefficient",
        "type": "int256",
        "internalType": "int256"
      },
      {
        "name": "exponent",
        "type": "int256",
        "internalType": "int256"
      }
    ]
  },
  {
    "type": "error",
    "name": "ScientificMinNotLessThanMax",
    "inputs": [
      {
        "name": "scientificMin",
        "type": "bytes32",
        "internalType": "Float"
      },
      {
        "name": "scientificMax",
        "type": "bytes32",
        "internalType": "Float"
      }
    ]
  },
  {
    "type": "error",
    "name": "UnformatableExponent",
    "inputs": [
      {
        "name": "exponent",
        "type": "int256",
        "internalType": "int256"
      }
    ]
  },
  {
    "type": "error",
    "name": "WithTargetExponentOverflow",
    "inputs": [
      {
        "name": "signedCoefficient",
        "type": "int256",
        "internalType": "int256"
      },
      {
        "name": "exponent",
        "type": "int256",
        "internalType": "int256"
      },
      {
        "name": "targetExponent",
        "type": "int256",
        "internalType": "int256"
      }
    ]
  },
  {
    "type": "error",
    "name": "ZeroNegativePower",
    "inputs": [
      {
        "name": "b",
        "type": "bytes32",
        "internalType": "Float"
      }
    ]
  },
  {
    "type": "error",
    "name": "ZeroStringStartPointer",
    "inputs": []
  }
]

Structs

CoefficientOverflow
Custom error with signature CoefficientOverflow(int256,int256) and selector 0x22c9f7bb.
DivisionByZero
Custom error with signature DivisionByZero(int256,int256) and selector 0x7a97930f.
ExponentOverflow
Custom error with signature ExponentOverflow(int256,int256) and selector 0xd556b111.
ExponentUnderflow
Custom error with signature ExponentUnderflow(int256,int256) and selector 0x8eba4d07.
FORMAT_DEFAULT_SCIENTIFIC_MAXCall
Function with signature FORMAT_DEFAULT_SCIENTIFIC_MAX() and selector 0x9b4afd99.
FORMAT_DEFAULT_SCIENTIFIC_MAXReturn
Container type for the return parameters of the FORMAT_DEFAULT_SCIENTIFIC_MAX() function.
FORMAT_DEFAULT_SCIENTIFIC_MINCall
Function with signature FORMAT_DEFAULT_SCIENTIFIC_MIN() and selector 0xd35273a7.
FORMAT_DEFAULT_SCIENTIFIC_MINReturn
Container type for the return parameters of the FORMAT_DEFAULT_SCIENTIFIC_MIN() function.
FixedDecimalOverflow
Custom error with signature FixedDecimalOverflow(int256,int256,uint8) and selector 0xc849483b.
Float
Log10Negative
Custom error with signature Log10Negative(int256,int256) and selector 0x5d3fd4db.
Log10Zero
Custom error with signature Log10Zero() and selector 0x561fc7b5.
LogTablesNotDeployed
Custom error with signature LogTablesNotDeployed(address,bytes32,bytes32) and selector 0x489687f8.
LossyConversionFromFloat
Custom error with signature LossyConversionFromFloat(int256,int256) and selector 0x05e47678.
LossyConversionToFloat
Custom error with signature LossyConversionToFloat(int256,int256) and selector 0xc4717966.
MaximizeOverflow
Custom error with signature MaximizeOverflow(int256,int256) and selector 0x05e51ecb.
MulDivOverflow
Custom error with signature MulDivOverflow(uint256,uint256,uint256) and selector 0x6c59da12.
NegativeFixedDecimalConversion
Custom error with signature NegativeFixedDecimalConversion(int256,int256) and selector 0x4a7d166b.
PowNegativeBase
Custom error with signature PowNegativeBase(int256,int256) and selector 0xcceba0f1.
ScientificMinNotLessThanMax
Custom error with signature ScientificMinNotLessThanMax(bytes32,bytes32) and selector 0x3be5bf94.
UnformatableExponent
Custom error with signature UnformatableExponent(int256) and selector 0xe44c72b0.
WithTargetExponentOverflow
Custom error with signature WithTargetExponentOverflow(int256,int256,int256) and selector 0x1d5d6d10.
ZeroNegativePower
Custom error with signature ZeroNegativePower(bytes32) and selector 0x8be82972.
ZeroStringStartPointer
Custom error with signature ZeroStringStartPointer() and selector 0xda6966d4.
absCall
Function with signature abs(bytes32) and selector 0x81a82272.
absReturn
Container type for the return parameters of the abs(bytes32) function.
addCall
Function with signature add(bytes32,bytes32) and selector 0xd1de592a.
addReturn
Container type for the return parameters of the add(bytes32,bytes32) function.
ceilCall
Function with signature ceil(bytes32) and selector 0x719cd99d.
ceilReturn
Container type for the return parameters of the ceil(bytes32) function.
constructorCall
Constructor`.
divCall
Function with signature div(bytes32,bytes32) and selector 0x30297400.
divReturn
Container type for the return parameters of the div(bytes32,bytes32) function.
eCall
Function with signature e() and selector 0xffae15ba.
eReturn
Container type for the return parameters of the e() function.
eqCall
Function with signature eq(bytes32,bytes32) and selector 0x3447c030.
eqReturn
Container type for the return parameters of the eq(bytes32,bytes32) function.
floorCall
Function with signature floor(bytes32) and selector 0x5ca0e7a4.
floorReturn
Container type for the return parameters of the floor(bytes32) function.
format_0Call
Function with signature format(bytes32,bool) and selector 0x371493ce.
format_0Return
Container type for the return parameters of the format(bytes32,bool) function.
format_1Call
Function with signature format(bytes32) and selector 0xa100a3d9.
format_1Return
Container type for the return parameters of the format(bytes32) function.
format_2Call
Function with signature format(bytes32,bytes32,bytes32) and selector 0xe5526ecd.
format_2Return
Container type for the return parameters of the format(bytes32,bytes32,bytes32) function.
fracCall
Function with signature frac(bytes32) and selector 0x28fa1f01.
fracReturn
Container type for the return parameters of the frac(bytes32) function.
fromFixedDecimalLosslessCall
Function with signature fromFixedDecimalLossless(uint256,uint8) and selector 0x3b3bd868.
fromFixedDecimalLosslessReturn
Container type for the return parameters of the fromFixedDecimalLossless(uint256,uint8) function.
fromFixedDecimalLossyCall
Function with signature fromFixedDecimalLossy(uint256,uint8) and selector 0xe75f991f.
fromFixedDecimalLossyReturn
Container type for the return parameters of the fromFixedDecimalLossy(uint256,uint8) function.
gtCall
Function with signature gt(bytes32,bytes32) and selector 0x8dc29807.
gtReturn
Container type for the return parameters of the gt(bytes32,bytes32) function.
gteCall
Function with signature gte(bytes32,bytes32) and selector 0x73bfb283.
gteReturn
Container type for the return parameters of the gte(bytes32,bytes32) function.
integerCall
Function with signature integer(bytes32) and selector 0xe0db5888.
integerReturn
Container type for the return parameters of the integer(bytes32) function.
invCall
Function with signature inv(bytes32) and selector 0x04327dc5.
invReturn
Container type for the return parameters of the inv(bytes32) function.
isZeroCall
Function with signature isZero(bytes32) and selector 0xdd646917.
isZeroReturn
Container type for the return parameters of the isZero(bytes32) function.
log10Call
Function with signature log10(bytes32) and selector 0x25388350.
log10Return
Container type for the return parameters of the log10(bytes32) function.
ltCall
Function with signature lt(bytes32,bytes32) and selector 0xd102b4d3.
ltReturn
Container type for the return parameters of the lt(bytes32,bytes32) function.
lteCall
Function with signature lte(bytes32,bytes32) and selector 0x81f7e2f5.
lteReturn
Container type for the return parameters of the lte(bytes32,bytes32) function.
maxCall
Function with signature max(bytes32,bytes32) and selector 0x078b665b.
maxNegativeValueCall
Function with signature maxNegativeValue() and selector 0x602c35fc.
maxNegativeValueReturn
Container type for the return parameters of the maxNegativeValue() function.
maxPositiveValueCall
Function with signature maxPositiveValue() and selector 0xcb09682b.
maxPositiveValueReturn
Container type for the return parameters of the maxPositiveValue() function.
maxReturn
Container type for the return parameters of the max(bytes32,bytes32) function.
minCall
Function with signature min(bytes32,bytes32) and selector 0xa90d041a.
minNegativeValueCall
Function with signature minNegativeValue() and selector 0xcde72ef3.
minNegativeValueReturn
Container type for the return parameters of the minNegativeValue() function.
minPositiveValueCall
Function with signature minPositiveValue() and selector 0xa19684b7.
minPositiveValueReturn
Container type for the return parameters of the minPositiveValue() function.
minReturn
Container type for the return parameters of the min(bytes32,bytes32) function.
minusCall
Function with signature minus(bytes32) and selector 0xd3d6ffa8.
minusReturn
Container type for the return parameters of the minus(bytes32) function.
mulCall
Function with signature mul(bytes32,bytes32) and selector 0x96ce1ec7.
mulReturn
Container type for the return parameters of the mul(bytes32,bytes32) function.
parseCall
Function with signature parse(string) and selector 0xbc62d8d8.
parseReturn
Container type for the return parameters of the parse(string) function.
pow10Call
Function with signature pow10(bytes32) and selector 0x1ee62f11.
pow10Return
Container type for the return parameters of the pow10(bytes32) function.
powCall
Function with signature pow(bytes32,bytes32) and selector 0x3004fa41.
powReturn
Container type for the return parameters of the pow(bytes32,bytes32) function.
sqrtCall
Function with signature sqrt(bytes32) and selector 0x146e82ad.
sqrtReturn
Container type for the return parameters of the sqrt(bytes32) function.
subCall
Function with signature sub(bytes32,bytes32) and selector 0x41aa0080.
subReturn
Container type for the return parameters of the sub(bytes32,bytes32) function.
toFixedDecimalLosslessCall
Function with signature toFixedDecimalLossless(bytes32,uint8) and selector 0x5b23771d.
toFixedDecimalLosslessReturn
Container type for the return parameters of the toFixedDecimalLossless(bytes32,uint8) function.
toFixedDecimalLossyCall
Function with signature toFixedDecimalLossy(bytes32,uint8) and selector 0x0b6429bc.
toFixedDecimalLossyReturn
Container type for the return parameters of the toFixedDecimalLossy(bytes32,uint8) function.
zeroCall
Function with signature zero() and selector 0xbc1b392d.
zeroReturn
Container type for the return parameters of the zero() function.

Enums

DecimalFloatCalls
Container for all the DecimalFloat function calls.
DecimalFloatErrors
Container for all the DecimalFloat custom errors.

Statics

BYTECODE
The creation / init bytecode of the contract.
DEPLOYED_BYTECODE
The runtime bytecode of the contract, as deployed on the network.