pub enum DecimalFloatErrors {
Show 19 variants
CoefficientOverflow(CoefficientOverflow),
DivisionByZero(DivisionByZero),
ExponentOverflow(ExponentOverflow),
ExponentUnderflow(ExponentUnderflow),
FixedDecimalOverflow(FixedDecimalOverflow),
Log10Negative(Log10Negative),
Log10Zero(Log10Zero),
LogTablesNotDeployed(LogTablesNotDeployed),
LossyConversionFromFloat(LossyConversionFromFloat),
LossyConversionToFloat(LossyConversionToFloat),
MaximizeOverflow(MaximizeOverflow),
MulDivOverflow(MulDivOverflow),
NegativeFixedDecimalConversion(NegativeFixedDecimalConversion),
PowNegativeBase(PowNegativeBase),
ScientificMinNotLessThanMax(ScientificMinNotLessThanMax),
UnformatableExponent(UnformatableExponent),
WithTargetExponentOverflow(WithTargetExponentOverflow),
ZeroNegativePower(ZeroNegativePower),
ZeroStringStartPointer(ZeroStringStartPointer),
}Expand description
Container for all the DecimalFloat custom errors.
Variants
CoefficientOverflow(CoefficientOverflow)
DivisionByZero(DivisionByZero)
ExponentOverflow(ExponentOverflow)
ExponentUnderflow(ExponentUnderflow)
FixedDecimalOverflow(FixedDecimalOverflow)
Log10Negative(Log10Negative)
Log10Zero(Log10Zero)
LogTablesNotDeployed(LogTablesNotDeployed)
LossyConversionFromFloat(LossyConversionFromFloat)
LossyConversionToFloat(LossyConversionToFloat)
MaximizeOverflow(MaximizeOverflow)
MulDivOverflow(MulDivOverflow)
NegativeFixedDecimalConversion(NegativeFixedDecimalConversion)
PowNegativeBase(PowNegativeBase)
ScientificMinNotLessThanMax(ScientificMinNotLessThanMax)
UnformatableExponent(UnformatableExponent)
WithTargetExponentOverflow(WithTargetExponentOverflow)
ZeroNegativePower(ZeroNegativePower)
ZeroStringStartPointer(ZeroStringStartPointer)
Implementations
Sourceimpl DecimalFloatErrors
impl DecimalFloatErrors
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl DecimalFloatErrors
impl DecimalFloatErrors
Sourcepub fn coefficient_overflow(signed_coefficient: I256, exponent: I256) -> Self
pub fn coefficient_overflow(signed_coefficient: I256, exponent: I256) -> Self
Creates a CoefficientOverflow error.
error CoefficientOverflow(int256,int256)Sourcepub fn division_by_zero(signed_coefficient: I256, exponent: I256) -> Self
pub fn division_by_zero(signed_coefficient: I256, exponent: I256) -> Self
Creates a DivisionByZero error.
error DivisionByZero(int256,int256)Sourcepub fn exponent_overflow(signed_coefficient: I256, exponent: I256) -> Self
pub fn exponent_overflow(signed_coefficient: I256, exponent: I256) -> Self
Creates a ExponentOverflow error.
error ExponentOverflow(int256,int256)Sourcepub fn exponent_underflow(signed_coefficient: I256, exponent: I256) -> Self
pub fn exponent_underflow(signed_coefficient: I256, exponent: I256) -> Self
Creates a ExponentUnderflow error.
error ExponentUnderflow(int256,int256)Sourcepub fn fixed_decimal_overflow(
signed_coefficient: I256,
exponent: I256,
decimals: u8,
) -> Self
pub fn fixed_decimal_overflow( signed_coefficient: I256, exponent: I256, decimals: u8, ) -> Self
Creates a FixedDecimalOverflow error.
error FixedDecimalOverflow(int256,int256,uint8)Sourcepub fn log_10_negative(signed_coefficient: I256, exponent: I256) -> Self
pub fn log_10_negative(signed_coefficient: I256, exponent: I256) -> Self
Creates a Log10Negative error.
error Log10Negative(int256,int256)Sourcepub fn log_10_zero() -> Self
pub fn log_10_zero() -> Self
Creates a Log10Zero error.
error Log10Zero()Sourcepub fn log_tables_not_deployed(
tables_address: Address,
expected_codehash: FixedBytes<32>,
actual_codehash: FixedBytes<32>,
) -> Self
pub fn log_tables_not_deployed( tables_address: Address, expected_codehash: FixedBytes<32>, actual_codehash: FixedBytes<32>, ) -> Self
Creates a LogTablesNotDeployed error.
error LogTablesNotDeployed(address,bytes32,bytes32)Sourcepub fn lossy_conversion_from_float(
signed_coefficient: I256,
exponent: I256,
) -> Self
pub fn lossy_conversion_from_float( signed_coefficient: I256, exponent: I256, ) -> Self
Creates a LossyConversionFromFloat error.
error LossyConversionFromFloat(int256,int256)Sourcepub fn lossy_conversion_to_float(
signed_coefficient: I256,
exponent: I256,
) -> Self
pub fn lossy_conversion_to_float( signed_coefficient: I256, exponent: I256, ) -> Self
Creates a LossyConversionToFloat error.
error LossyConversionToFloat(int256,int256)Sourcepub fn maximize_overflow(signed_coefficient: I256, exponent: I256) -> Self
pub fn maximize_overflow(signed_coefficient: I256, exponent: I256) -> Self
Creates a MaximizeOverflow error.
error MaximizeOverflow(int256,int256)Sourcepub fn mul_div_overflow(x: U256, y: U256, denominator: U256) -> Self
pub fn mul_div_overflow(x: U256, y: U256, denominator: U256) -> Self
Creates a MulDivOverflow error.
error MulDivOverflow(uint256,uint256,uint256)Sourcepub fn negative_fixed_decimal_conversion(
signed_coefficient: I256,
exponent: I256,
) -> Self
pub fn negative_fixed_decimal_conversion( signed_coefficient: I256, exponent: I256, ) -> Self
Creates a NegativeFixedDecimalConversion error.
error NegativeFixedDecimalConversion(int256,int256)Sourcepub fn pow_negative_base(signed_coefficient: I256, exponent: I256) -> Self
pub fn pow_negative_base(signed_coefficient: I256, exponent: I256) -> Self
Creates a PowNegativeBase error.
error PowNegativeBase(int256,int256)Sourcepub fn scientific_min_not_less_than_max(
scientific_min: <Float as SolType>::RustType,
scientific_max: <Float as SolType>::RustType,
) -> Self
pub fn scientific_min_not_less_than_max( scientific_min: <Float as SolType>::RustType, scientific_max: <Float as SolType>::RustType, ) -> Self
Creates a ScientificMinNotLessThanMax error.
error ScientificMinNotLessThanMax(bytes32,bytes32)Sourcepub fn unformatable_exponent(exponent: I256) -> Self
pub fn unformatable_exponent(exponent: I256) -> Self
Creates a UnformatableExponent error.
error UnformatableExponent(int256)Sourcepub fn with_target_exponent_overflow(
signed_coefficient: I256,
exponent: I256,
target_exponent: I256,
) -> Self
pub fn with_target_exponent_overflow( signed_coefficient: I256, exponent: I256, target_exponent: I256, ) -> Self
Creates a WithTargetExponentOverflow error.
error WithTargetExponentOverflow(int256,int256,int256)Sourcepub fn zero_negative_power(b: <Float as SolType>::RustType) -> Self
pub fn zero_negative_power(b: <Float as SolType>::RustType) -> Self
Creates a ZeroNegativePower error.
error ZeroNegativePower(bytes32)Sourcepub fn zero_string_start_pointer() -> Self
pub fn zero_string_start_pointer() -> Self
Creates a ZeroStringStartPointer error.
error ZeroStringStartPointer()Trait Implementations
Sourceimpl Clone for DecimalFloatErrors
impl Clone for DecimalFloatErrors
Sourcefn clone(&self) -> DecimalFloatErrors
fn clone(&self) -> DecimalFloatErrors
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DecimalFloatErrors
impl Debug for DecimalFloatErrors
impl Eq for DecimalFloatErrors
Sourceimpl Hash for DecimalFloatErrors
impl Hash for DecimalFloatErrors
Sourceimpl PartialEq for DecimalFloatErrors
impl PartialEq for DecimalFloatErrors
Sourceimpl SolInterface for DecimalFloatErrors
impl SolInterface for DecimalFloatErrors
Sourceconst MIN_DATA_LENGTH: usize = 0usize
const MIN_DATA_LENGTH: usize = 0usize
Sourcefn valid_selector(selector: [u8; 4]) -> bool
fn valid_selector(selector: [u8; 4]) -> bool
true if the given selector is known to this type.Sourcefn abi_decode_raw(selector: [u8; 4], data: &[u8]) -> Result<Self>
fn abi_decode_raw(selector: [u8; 4], data: &[u8]) -> Result<Self>
self.Sourcefn abi_decode_raw_validate(selector: [u8; 4], data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(selector: [u8; 4], data: &[u8]) -> Result<Self>
self, with validation. Read moreSourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
self into the given buffer, without any selectors.Sourcefn type_check(selector: [u8; 4]) -> Result<(), Error>
fn type_check(selector: [u8; 4]) -> Result<(), Error>
impl StructuralPartialEq for DecimalFloatErrors