pub struct ExponentUnderflow {
pub signedCoefficient: I256,
pub exponent: I256,
}Expand description
Custom error with signature ExponentUnderflow(int256,int256) and selector 0x8eba4d07.
error ExponentUnderflow(int256 signedCoefficient, int256 exponent);Fields
signedCoefficient: I256exponent: I256Trait Implementations
Sourceimpl Clone for ExponentUnderflow
impl Clone for ExponentUnderflow
Sourcefn clone(&self) -> ExponentUnderflow
fn clone(&self) -> ExponentUnderflow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExponentUnderflow
impl Debug for ExponentUnderflow
Sourceimpl Default for ExponentUnderflow
impl Default for ExponentUnderflow
Sourcefn default() -> ExponentUnderflow
fn default() -> ExponentUnderflow
Returns the “default value” for a type. Read more
Sourceimpl Hash for ExponentUnderflow
impl Hash for ExponentUnderflow
Sourceimpl PartialEq for ExponentUnderflow
impl PartialEq for ExponentUnderflow
Sourcefn eq(&self, other: &ExponentUnderflow) -> bool
fn eq(&self, other: &ExponentUnderflow) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl SolError for ExponentUnderflow
impl SolError for ExponentUnderflow
Sourcetype Parameters<'a> = (Int<256>, Int<256>)
type Parameters<'a> = (Int<256>, Int<256>)
The underlying tuple type which represents the error’s members. Read more
Sourcetype Token<'a> = <<ExponentUnderflow as SolError>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<ExponentUnderflow as SolError>::Parameters<'a> as SolType>::Token<'a>
The corresponding
TokenSeq type.Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> Self::Token<'_>
fn tokenize(&self) -> Self::Token<'_>
Convert to the token type used for EIP-712 encoding and decoding.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
ABI decode this error’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the error params when encoded in bytes, without the
selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the error to the given buffer without its selector.
impl Eq for ExponentUnderflow
impl StructuralPartialEq for ExponentUnderflow