pub struct UnformatableExponent {
pub exponent: I256,
}Expand description
Custom error with signature UnformatableExponent(int256) and selector 0xe44c72b0.
error UnformatableExponent(int256 exponent);Fields
exponent: I256Trait Implementations
Sourceimpl Clone for UnformatableExponent
impl Clone for UnformatableExponent
Sourcefn clone(&self) -> UnformatableExponent
fn clone(&self) -> UnformatableExponent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnformatableExponent
impl Debug for UnformatableExponent
Sourceimpl Default for UnformatableExponent
impl Default for UnformatableExponent
Sourcefn default() -> UnformatableExponent
fn default() -> UnformatableExponent
Returns the “default value” for a type. Read more
impl Eq for UnformatableExponent
Sourceimpl Hash for UnformatableExponent
impl Hash for UnformatableExponent
Sourceimpl PartialEq for UnformatableExponent
impl PartialEq for UnformatableExponent
Sourceimpl SolError for UnformatableExponent
impl SolError for UnformatableExponent
Sourcetype Parameters<'a> = (Int<256>,)
type Parameters<'a> = (Int<256>,)
The underlying tuple type which represents the error’s members. Read more
Sourcetype Token<'a> = <<UnformatableExponent as SolError>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<UnformatableExponent as SolError>::Parameters<'a> as SolType>::Token<'a>
The corresponding
TokenSeq type.Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> Self::Token<'_>
fn tokenize(&self) -> Self::Token<'_>
Convert to the token type used for EIP-712 encoding and decoding.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
ABI decode this error’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the error params when encoded in bytes, without the
selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the error to the given buffer without its selector.
impl StructuralPartialEq for UnformatableExponent