pub struct WithTargetExponentOverflow {
pub signedCoefficient: I256,
pub exponent: I256,
pub targetExponent: I256,
}Expand description
Custom error with signature WithTargetExponentOverflow(int256,int256,int256) and selector 0x1d5d6d10.
error WithTargetExponentOverflow(int256 signedCoefficient, int256 exponent, int256 targetExponent);Fields
signedCoefficient: I256exponent: I256targetExponent: I256Trait Implementations
Sourceimpl Clone for WithTargetExponentOverflow
impl Clone for WithTargetExponentOverflow
Sourcefn clone(&self) -> WithTargetExponentOverflow
fn clone(&self) -> WithTargetExponentOverflow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WithTargetExponentOverflow
impl Debug for WithTargetExponentOverflow
Sourceimpl Default for WithTargetExponentOverflow
impl Default for WithTargetExponentOverflow
Sourcefn default() -> WithTargetExponentOverflow
fn default() -> WithTargetExponentOverflow
Returns the “default value” for a type. Read more
impl Eq for WithTargetExponentOverflow
Sourceimpl Hash for WithTargetExponentOverflow
impl Hash for WithTargetExponentOverflow
Sourceimpl SolError for WithTargetExponentOverflow
impl SolError for WithTargetExponentOverflow
Sourceconst SIGNATURE: &'static str = "WithTargetExponentOverflow(int256,int256,int256)"
const SIGNATURE: &'static str = "WithTargetExponentOverflow(int256,int256,int256)"
The error’s ABI signature.
Sourcetype Parameters<'a> = (Int<256>, Int<256>, Int<256>)
type Parameters<'a> = (Int<256>, Int<256>, Int<256>)
The underlying tuple type which represents the error’s members. Read more
Sourcetype Token<'a> = <<WithTargetExponentOverflow as SolError>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<WithTargetExponentOverflow as SolError>::Parameters<'a> as SolType>::Token<'a>
The corresponding
TokenSeq type.Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> Self::Token<'_>
fn tokenize(&self) -> Self::Token<'_>
Convert to the token type used for EIP-712 encoding and decoding.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
ABI decode this error’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the error params when encoded in bytes, without the
selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the error to the given buffer without its selector.
impl StructuralPartialEq for WithTargetExponentOverflow